# Chat Templates

<!-- pyml disable-num-lines 3 line-length -->

- llama3.1_chat_template_vllm.jinja:
  <https://github.com/vllm-project/vllm/blob/4fb8e329fd6f51d576bcf4b7e8907e0d83c4b5cf/examples/tool_chat_template_llama3.1_json.jinja>
- llama3.1_chat_template_hf.jinja:
  <https://huggingface.co/meta-llama/Llama-3.1-8B-Instruct/blob/main/tokenizer_config.json#L2053>
- llama3.1_chat_template_thought.jinja: Fixes a typo in llama3.1_chat_template_ori.jinja
- llama3.1_chat_template_nothought.jinja: Derived from llama3.1_chat_template_ori.jinja, but removes thoughts
- llama\*ori.jinja: TODOC - these were written by @kwanUm
